@@ -1,14 +1,11 @@
-#ifndef lint
-static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/frames.c,v 1.14 1998/02/12 03:08:57 unammx Exp $";
-#endif
 /*****
 * frames.c : XmHTML frame support
 *
-* This file Version	$Revision: 1.14 $
+* This file Version	$Revision: 1.15 $
 *
 * Creation date:		Tue Mar 25 18:53:12 GMT+0100 1997
-* Last modification: 	$Date: 1998/02/12 03:08:57 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -36,6 +33,11 @@ static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/frames.c,v 1.14 1
 /*****
 * ChangeLog 
 * $Log: frames.c,v $
+* Revision 1.15  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.14  1998/02/12 03:08:57  unammx
 * Merge to Koen's XmHTML 1.1.2 + following fixes:
 *
