@@ -22,6 +22,12 @@
 #ifndef __ART_GRAY_SVP_H__
 #define __ART_GRAY_SVP_H__
 
+#ifdef LIBART_COMPILATION
+#include "art_svp.h"
+#else
+#include <libart_lgpl/art_svp.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
