@@ -294,8 +294,8 @@ static const struct poptOption gnome_options[] = {
 static void
 gnome_register_options(void)
 {
-	gnomelib_register_popt_table(gtk_options, _("GTK options"));
-	gnomelib_register_popt_table(gnome_options, _("GNOME GUI options"));
+	gnomelib_register_popt_table(gtk_options, N_("GTK options"));
+	gnomelib_register_popt_table(gnome_options, N_("GNOME GUI options"));
 }
 
 /* #define ALLOC_DEBUGGING_HOOKS */
@@ -451,7 +451,6 @@ gnome_init_with_popt_table(const char *app_id,
 	if(options) {
 		appdesc = g_strdup_printf(_("%s options"), app_id);
 		gnomelib_register_popt_table(options, appdesc);
-		g_free(appdesc);
 	}
 	
 	ctx = gnomelib_parse_args(argc, argv, flags);
